@@ -3,7 +3,7 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {shortDate} from 'gmp/locale/date';
+import {formattedUserSettingShortDate} from 'web/utils/userSettingTimeDateFormatters';
 
 import {parseInt, parseDate} from 'gmp/parser';
 
@@ -14,7 +14,7 @@ const transformCreated = (data = {}) => {
     const createdDate = parseDate(value);
     return {
       x: createdDate,
-      label: shortDate(createdDate),
+      label: formattedUserSettingShortDate(createdDate),
       y: parseInt(count),
       y2: parseInt(c_count),
     };
