@@ -3,14 +3,19 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {dateTimeWithTimeZone, ensureDate} from 'gmp/locale/date';
+import {ensureDate} from 'gmp/locale/date';
+import {formattedUserSettingDateTimeWithTimeZone} from 'web/utils/userSettingTimeDateFormatters';
 
 import {isDefined, hasValue} from 'gmp/utils/identity';
 
 import PropTypes from 'web/utils/proptypes';
 import useUserTimezone from 'web/hooks/useUserTimezone';
 
-const DateTime = ({formatter = dateTimeWithTimeZone, timezone, date}) => {
+const DateTime = ({
+  formatter = formattedUserSettingDateTimeWithTimeZone,
+  timezone,
+  date,
+}) => {
   date = ensureDate(date);
 
   const [userTimezone] = useUserTimezone();
@@ -18,6 +23,7 @@ const DateTime = ({formatter = dateTimeWithTimeZone, timezone, date}) => {
   if (!hasValue(timezone)) {
     timezone = userTimezone;
   }
+
   return !isDefined(date) || !date.isValid() ? null : formatter(date, timezone);
 };
 
