@@ -6,7 +6,6 @@
 import {describe, test, expect, testing} from '@gsa/testing';
 
 import {render, fireEvent, screen} from 'web/utils/testing';
-import Theme from 'web/utils/theme';
 
 import DialogError from '../error';
 
@@ -16,14 +15,15 @@ describe('Dialog error tests', () => {
       <DialogError error="foo" onCloseClick={() => {}} />,
     );
 
+    expect(element).toBeInTheDocument();
     expect(element).toHaveTextContent('foo');
-    expect(element).toHaveStyleRule('background-color', Theme.lightRed);
   });
 
   test('should not render with undefined error', () => {
-    const {element} = render(<DialogError onCloseClick={() => {}} />);
+    const {container} = render(<DialogError onCloseClick={() => {}} />);
 
-    expect(element).toBe(null);
+    const divElement = container.querySelector('div');
+    expect(divElement).not.toBeInTheDocument();
   });
 
   test('should call close handler', () => {
