@@ -3,31 +3,27 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
 import React from 'react';
 
 import styled from 'styled-components';
 
 import PropTypes from 'web/utils/proptypes';
 
-import Theme from 'web/utils/theme';
-
 import Layout from 'web/components/layout/layout';
 
-import Button from './button';
+import Button from 'web/components/form/button';
 
 export const DialogFooterLayout = styled(Layout)`
-  border-width: 1px 0 0 0;
-  border-style: solid;
-  border-color: ${Theme.lightGray};
   margin-top: 15px;
-  padding: 10px 20px 10px 20px;
+  padding: 10px 0px 0px 0px;
+  gap: 10px;
 `;
 
 const DialogFooter = ({
   title,
   onClick,
   loading = false,
+  isLoading = loading,
   'data-testid': dataTestId,
 }) => (
   <DialogFooterLayout
@@ -35,7 +31,7 @@ const DialogFooter = ({
     shrink="0"
     data-testid={dataTestId}
   >
-    <Button onClick={onClick} title={title} loading={loading}>
+    <Button onClick={onClick} title={title} isLoading={isLoading}>
       {title}
     </Button>
   </DialogFooterLayout>
@@ -43,6 +39,7 @@ const DialogFooter = ({
 
 DialogFooter.propTypes = {
   'data-testid': PropTypes.string,
+  isLoading: PropTypes.bool,
   loading: PropTypes.bool,
   title: PropTypes.string.isRequired,
   onClick: PropTypes.func,
