@@ -12,20 +12,18 @@ import FileField from '../filefield';
 describe('FileField tests', () => {
   test('should render', () => {
     const {element} = render(<FileField />);
-    expect(element).toMatchSnapshot();
-  });
 
-  test('should render in disabled state', () => {
-    const {element} = render(<FileField disabled={true} />);
-    expect(element).toMatchSnapshot();
+    expect(element).toBeInTheDocument();
   });
 
   test('should call change handler with file', () => {
     const onChange = testing.fn();
 
-    const {element} = render(<FileField onChange={onChange} />);
+    const {baseElement} = render(<FileField onChange={onChange} />);
 
-    fireEvent.change(element, {target: {files: ['bar']}});
+    const input = baseElement.querySelector('input[type=file]');
+
+    fireEvent.change(input, {target: {files: ['bar']}});
 
     expect(onChange).toHaveBeenCalledWith('bar', undefined);
   });
@@ -33,9 +31,11 @@ describe('FileField tests', () => {
   test('should call change handler with file and name', () => {
     const onChange = testing.fn();
 
-    const {element} = render(<FileField name="foo" onChange={onChange} />);
+    const {baseElement} = render(<FileField name="foo" onChange={onChange} />);
 
-    fireEvent.change(element, {target: {files: ['bar']}});
+    const input = baseElement.querySelector('input[type=file]');
+
+    fireEvent.change(input, {target: {files: ['bar']}});
 
     expect(onChange).toHaveBeenCalledWith('bar', 'foo');
   });
@@ -43,9 +43,13 @@ describe('FileField tests', () => {
   test('should not call change handler if disabled', () => {
     const onChange = testing.fn();
 
-    const {element} = render(<FileField disabled={true} onChange={onChange} />);
+    const {baseElement} = render(
+      <FileField disabled={true} onChange={onChange} />,
+    );
 
-    fireEvent.change(element, {target: {files: ['bar']}});
+    const input = baseElement.querySelector('input[type=file]');
+
+    fireEvent.change(input, {target: {files: ['bar']}});
 
     expect(onChange).not.toHaveBeenCalled();
   });
