@@ -3,10 +3,7 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
-import React from 'react';
-
-import _ from 'gmp/locale';
+import React, {useMemo} from 'react';
 
 import {map} from 'gmp/utils/array';
 
@@ -14,29 +11,27 @@ import timezones from 'gmp/timezones';
 
 import PropTypes from 'web/utils/proptypes';
 
+import useTranslation from 'web/hooks/useTranslation';
+
 import Select from './select';
 
 const TimeZoneSelectComponent = ({value = 'UTC', ...props}) => {
-  const timezoneItems = [
-    {
-      label: _('Coordinated Universal Time/UTC'),
-      value: 'UTC',
-    },
-    ...map(timezones, ({name}) => ({
-      label: name,
-      value: name,
-    })),
-  ];
-
-  return (
-    <Select
-      {...props}
-      items={timezoneItems}
-      menuPosition="adjust"
-      value={value}
-      width="230px"
-    />
+  const [_] = useTranslation();
+  const timezoneItems = useMemo(
+    () => [
+      {
+        label: _('Coordinated Universal Time/UTC'),
+        value: 'UTC',
+      },
+      ...map(timezones, ({name}) => ({
+        label: name,
+        value: name,
+      })),
+    ],
+    [_],
   );
+
+  return <Select {...props} items={timezoneItems} value={value} />;
 };
 
 TimeZoneSelectComponent.propTypes = {
