@@ -3,11 +3,8 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
 import React from 'react';
 
-import _ from 'gmp/locale';
-
 import {isString} from 'gmp/utils/identity';
 
 import PropTypes from 'web/utils/proptypes';
@@ -15,7 +12,10 @@ import PropTypes from 'web/utils/proptypes';
 import FormGroup from 'web/components/form/formgroup';
 import TextField from 'web/components/form/textfield';
 
+import useTranslation from 'web/hooks/useTranslation';
+
 const FilterStringGroup = ({filter, onChange, name = 'filter'}) => {
+  const [_] = useTranslation();
   const filterstring = isString(filter)
     ? filter
     : filter.toFilterCriteriaString();
@@ -41,4 +41,3 @@ FilterStringGroup.propTypes = {
 export default FilterStringGroup;
 
 // vim: set ts=2 sw=2 tw=80:
-
