@@ -5,37 +5,34 @@
 
 import React from 'react';
 
-import _ from 'gmp/locale';
-
 import {isDefined} from 'gmp/utils/identity';
 
 import PropTypes from 'web/utils/proptypes';
 
-import FormGroup from '../form/formgroup';
-import Spinner from '../form/spinner';
+import FormGroup from 'web/components/form/formgroup';
+import Spinner from 'web/components/form/spinner';
 
-import Divider from '../layout/divider';
+import useTranslation from 'web/hooks/useTranslation';
 
 const MinQodGroup = ({qod, onChange, filter, name = 'min_qod'}) => {
+  const [_] = useTranslation();
+
   if (!isDefined(qod) && isDefined(filter)) {
     qod = filter.get('min_qod');
   }
   return (
-    <FormGroup title={_('QoD')}>
-      <Divider>
-        <span>{_('must be at least')}</span>
-        <Spinner
-          type="int"
-          name={name}
-          min="0"
-          max="100"
-          step="1"
-          value={qod}
-          size="1"
-          onChange={onChange}
-        />
-        <span>%</span>
-      </Divider>
+    <FormGroup title={_('QoD')} direction="row">
+      <span>{_('must be at least')}</span>
+      <Spinner
+        type="int"
+        name={name}
+        min="0"
+        max="100"
+        step="1"
+        value={qod}
+        onChange={onChange}
+      />
+      <span>%</span>
     </FormGroup>
   );
 };
