@@ -7,8 +7,6 @@
 /* eslint-disable react/prop-types */
 import React from 'react';
 
-import _ from 'gmp/locale';
-
 import {isDefined} from 'gmp/utils/identity';
 
 import PropTypes from 'web/utils/proptypes';
@@ -16,7 +14,10 @@ import PropTypes from 'web/utils/proptypes';
 import FormGroup from 'web/components/form/formgroup';
 import Select from 'web/components/form/select';
 
+import useTranslation from 'web/hooks/useTranslation';
+
 const TaskTrendGroup = ({trend, name = 'trend', filter, onChange}) => {
+  const [_] = useTranslation();
   if (!isDefined(trend) && isDefined(filter)) {
     trend = filter.get('trend');
   }
