@@ -6,7 +6,7 @@
 
 import React from 'react';
 
-import {withRouter} from 'react-router-dom';
+import {withRouter} from 'web/utils/withRouter';
 
 import {connect} from 'react-redux';
 
@@ -321,17 +321,18 @@ class EntitiesContainer extends React.Component {
     this.changeFilter(RESET_FILTER);
   }
 
-  handleFilterReset() {
-    const {history, location} = this.props;
-    const query = {...location.query};
+  handleFilterReset = () => {
+    const {navigate, location, searchParams} = this.props;
 
-    // remove filter param from url
-    delete query.filter;
+    searchParams.delete('filter');
 
-    history.push({pathname: location.pathname, query});
+    navigate({
+      pathname: location.pathname,
+      search: searchParams.toString(),
+    });
 
     this.changeFilter();
-  }
+  };
 
   openTagDialog() {
     this.setState({tagDialogVisible: true});
@@ -475,6 +476,7 @@ class EntitiesContainer extends React.Component {
     const {
       children,
       isLoading,
+      isGenericBulkTrashcanDeleteDialog = true,
       onDownload,
       showErrorMessage,
       showSuccessMessage,
@@ -519,6 +521,7 @@ class EntitiesContainer extends React.Component {
           filter: loadedFilter,
           isLoading,
           isUpdating,
+          isGenericBulkTrashcanDeleteDialog,
           selectionType: selectionType,
           sortBy,
           sortDir,
@@ -583,10 +586,13 @@ EntitiesContainer.propTypes = {
   entitiesCounts: PropTypes.counts,
   entitiesError: PropTypes.error,
   filter: PropTypes.filter,
+  searchParams: PropTypes.object,
+  location: PropTypes.object,
   gmp: PropTypes.gmp.isRequired,
   gmpname: PropTypes.string.isRequired,
-  history: PropTypes.object.isRequired,
+  navigate: PropTypes.object.isRequired,
   isLoading: PropTypes.bool.isRequired,
+  isGenericBulkTrashcanDeleteDialog: PropTypes.bool,
   listExportFileName: PropTypes.string,
   loadSettings: PropTypes.func.isRequired,
   loadedFilter: PropTypes.filter,
@@ -604,9 +610,8 @@ EntitiesContainer.propTypes = {
 const mapStateToProps = rootState => {
   const userDefaultsSelector = getUserSettingsDefaults(rootState);
   const username = getUsername(rootState);
-  const listExportFileName = userDefaultsSelector.getValueByName(
-    'listexportfilename',
-  );
+  const listExportFileName =
+    userDefaultsSelector.getValueByName('listexportfilename');
   return {
     listExportFileName,
     username,
