@@ -7,24 +7,20 @@
 import {describe, test, expect, testing} from '@gsa/testing';
 
 import Capabilities from 'gmp/capabilities/capabilities';
-import {setLocale} from 'gmp/locale/lang';
 
 import Audit, {AUDIT_STATUS} from 'gmp/models/audit';
 import {GREENBONE_SENSOR_SCANNER_TYPE} from 'gmp/models/scanner';
 
 import {setTimezone, setUsername} from 'web/store/usersettings/actions';
 
-import {rendererWith, fireEvent} from 'web/utils/testing';
+import {screen, rendererWith, fireEvent} from 'web/utils/testing';
+
+import {getActionItems} from 'web/components/testing';
 
 import Row from '../row';
 
-setLocale('en');
-
 const gmp = {settings: {}};
-const featureList = [
-  {name: 'COMPLIANCE_REPORTS', _enabled: 0},
-];
-const caps = new Capabilities(['everything'], featureList);
+const caps = new Capabilities(['everything']);
 
 const lastReport = {
   report: {
@@ -81,7 +77,7 @@ describe('Audit Row tests', () => {
     store.dispatch(setTimezone('CET'));
     store.dispatch(setUsername('username'));
 
-    const {baseElement, getAllByTestId} = render(
+    const {element} = render(
       <Row
         entity={audit}
         links={true}
@@ -98,33 +94,33 @@ describe('Audit Row tests', () => {
       />,
     );
 
-    expect(baseElement).toBeVisible();
+    expect(element).toBeVisible();
 
     // Name
-    expect(baseElement).toHaveTextContent('foo');
-    expect(baseElement).toHaveTextContent('(bar)');
+    expect(element).toHaveTextContent('foo');
+    expect(element).toHaveTextContent('(bar)');
 
     // Status
-    const bars = getAllByTestId('progressbar-box');
+    const bars = screen.getAllByTestId('progressbar-box');
 
     expect(bars[0]).toHaveAttribute('title', AUDIT_STATUS.done);
     expect(bars[0]).toHaveTextContent(AUDIT_STATUS.done);
 
-    const detailsLinks = getAllByTestId('details-link');
+    const detailsLinks = screen.getAllByTestId('details-link');
 
     expect(detailsLinks[0]).toHaveTextContent('Done');
-    expect(detailsLinks[0]).toHaveAttribute('href', '/report/1234');
+    expect(detailsLinks[0]).toHaveAttribute('href', '/auditreport/1234');
 
     // Report
     expect(detailsLinks[1]).toHaveTextContent('Wed, Jul 10, 2019 2:51 PM CEST');
-    expect(detailsLinks[1]).toHaveAttribute('href', '/report/1234');
+    expect(detailsLinks[1]).toHaveAttribute('href', '/auditreport/1234');
 
     // Compliance Status
     expect(bars[1]).toHaveAttribute('title', '50%');
     expect(bars[1]).toHaveTextContent('50%');
 
     // Actions
-    const icons = getAllByTestId('svg-icon');
+    const icons = getActionItems();
 
     expect(icons[0]).toHaveAttribute('title', 'Start');
     expect(icons[1]).toHaveAttribute('title', 'Audit is not stopped');
@@ -181,7 +177,7 @@ describe('Audit Row tests', () => {
     store.dispatch(setTimezone('CET'));
     store.dispatch(setUsername('username'));
 
-    const {getAllByTestId} = render(
+    render(
       <Row
         entity={audit}
         links={true}
@@ -198,7 +194,7 @@ describe('Audit Row tests', () => {
       />,
     );
 
-    const icons = getAllByTestId('svg-icon');
+    const icons = getActionItems();
 
     expect(icons[0]).toHaveAttribute('title', 'Audit is alterable');
     expect(icons[1]).toHaveAttribute(
@@ -276,7 +272,7 @@ describe('Audit Row tests', () => {
     expect(detailsLinks.length).toBe(0);
     // because there are no reports yet
 
-    // Compliance Satus
+    // Compliance Status
     expect(bars.length).toBe(1);
     // because there is no compliance status bar yet
 
@@ -378,18 +374,18 @@ describe('Audit Row tests', () => {
     const detailsLinks = getAllByTestId('details-link');
 
     expect(detailsLinks[0]).toHaveTextContent('0 %');
-    expect(detailsLinks[0]).toHaveAttribute('href', '/report/5678');
+    expect(detailsLinks[0]).toHaveAttribute('href', '/auditreport/5678');
 
     // Report
     expect(detailsLinks.length).toBe(1);
     // because there is no last report yet
 
-    // Compliance Satus
+    // Compliance Status
     expect(bars.length).toBe(1);
     // because there is no compliance status bar yet
 
     // Actions
-    const icons = getAllByTestId('svg-icon');
+    const icons = getActionItems();
 
     fireEvent.click(icons[0]);
     expect(handleAuditStart).not.toHaveBeenCalled();
@@ -486,18 +482,18 @@ describe('Audit Row tests', () => {
     const detailsLinks = getAllByTestId('details-link');
 
     expect(detailsLinks[0]).toHaveTextContent('Stopped');
-    expect(detailsLinks[0]).toHaveAttribute('href', '/report/5678');
+    expect(detailsLinks[0]).toHaveAttribute('href', '/auditreport/5678');
 
     // Report
     expect(detailsLinks[1]).toHaveTextContent('Wed, Jul 10, 2019 2:51 PM CEST');
-    expect(detailsLinks[1]).toHaveAttribute('href', '/report/1234');
+    expect(detailsLinks[1]).toHaveAttribute('href', '/auditreport/1234');
 
     // Compliance Status
     expect(bars[1]).toHaveAttribute('title', '50%');
     expect(bars[1]).toHaveTextContent('50%');
 
     // Actions
-    const icons = getAllByTestId('svg-icon');
+    const icons = getActionItems();
 
     fireEvent.click(icons[0]);
     expect(handleAuditStart).toHaveBeenCalledWith(audit);
@@ -596,18 +592,18 @@ describe('Audit Row tests', () => {
     const detailsLinks = getAllByTestId('details-link');
 
     expect(detailsLinks[0]).toHaveTextContent('Done');
-    expect(detailsLinks[0]).toHaveAttribute('href', '/report/1234');
+    expect(detailsLinks[0]).toHaveAttribute('href', '/auditreport/1234');
 
     // Report
     expect(detailsLinks[1]).toHaveTextContent('Wed, Jul 10, 2019 2:51 PM CEST');
-    expect(detailsLinks[1]).toHaveAttribute('href', '/report/1234');
+    expect(detailsLinks[1]).toHaveAttribute('href', '/auditreport/1234');
 
     // Compliance Status
     expect(bars[1]).toHaveAttribute('title', '50%');
     expect(bars[1]).toHaveTextContent('50%');
 
     // Actions
-    const icons = getAllByTestId('svg-icon');
+    const icons = getActionItems();
 
     fireEvent.click(icons[0]);
     expect(handleAuditStart).toHaveBeenCalledWith(audit);
@@ -697,7 +693,7 @@ describe('Audit Row tests', () => {
     fireEvent.click(spans[0]);
     expect(handleToggleDetailsClick).toHaveBeenCalledWith(undefined, '314');
 
-    const icons = getAllByTestId('svg-icon');
+    const icons = getActionItems();
     expect(icons[0]).toHaveAttribute('title', 'Audit owned by user');
 
     // Status
@@ -709,11 +705,11 @@ describe('Audit Row tests', () => {
     const detailsLinks = getAllByTestId('details-link');
 
     expect(detailsLinks[0]).toHaveTextContent('Done');
-    expect(detailsLinks[0]).toHaveAttribute('href', '/report/1234');
+    expect(detailsLinks[0]).toHaveAttribute('href', '/auditreport/1234');
 
     // Report
     expect(detailsLinks[1]).toHaveTextContent('Wed, Jul 10, 2019 2:51 PM CEST');
-    expect(detailsLinks[1]).toHaveAttribute('href', '/report/1234');
+    expect(detailsLinks[1]).toHaveAttribute('href', '/auditreport/1234');
 
     // Compliance Status
     expect(bars[1]).toHaveAttribute('title', '50%');
@@ -763,104 +759,3 @@ describe('Audit Row tests', () => {
 
   console.warn = consoleError;
 });
-
-describe('Audit Row tests - compliance reports enabled', () => {
-  // deactivate console.error for tests
-  // to make it possible to test a row without a table
-  console.error = () => {};
-  const featureList = [
-    {name: 'COMPLIANCE_REPORTS', _enabled: 1},
-  ];
-  const caps = new Capabilities(['everything'], featureList);
-
-  test('should render', () => {
-    const audit = Audit.fromElement({
-      _id: '314',
-      owner: {name: 'username'},
-      name: 'foo',
-      comment: 'bar',
-      status: AUDIT_STATUS.done,
-      alterable: '0',
-      last_report: lastReport,
-      permissions: {permission: [{name: 'everything'}]},
-      target: {_id: '5678', name: 'target'},
-      usage_type: 'audit',
-    });
-
-    const handleAuditClone = testing.fn();
-    const handleAuditDelete = testing.fn();
-    const handleAuditDownload = testing.fn();
-    const handleAuditEdit = testing.fn();
-    const handleAuditResume = testing.fn();
-    const handleAuditStart = testing.fn();
-    const handleAuditStop = testing.fn();
-    const handleReportDownload = testing.fn();
-    const handleToggleDetailsClick = testing.fn();
-
-    const {render, store} = rendererWith({
-      gmp,
-      capabilities: caps,
-      store: true,
-      router: true,
-    });
-
-    store.dispatch(setTimezone('CET'));
-    store.dispatch(setUsername('username'));
-
-    const {baseElement, getAllByTestId} = render(
-      <Row
-        entity={audit}
-        links={true}
-        gcrFormatDefined={true}
-        onAuditCloneClick={handleAuditClone}
-        onAuditDeleteClick={handleAuditDelete}
-        onAuditDownloadClick={handleAuditDownload}
-        onAuditEditClick={handleAuditEdit}
-        onAuditResumeClick={handleAuditResume}
-        onAuditStartClick={handleAuditStart}
-        onAuditStopClick={handleAuditStop}
-        onReportDownloadClick={handleReportDownload}
-        onToggleDetailsClick={handleToggleDetailsClick}
-      />,
-    );
-
-    expect(baseElement).toBeVisible();
-
-    // Name
-    expect(baseElement).toHaveTextContent('foo');
-    expect(baseElement).toHaveTextContent('(bar)');
-
-    // Status
-    const bars = getAllByTestId('progressbar-box');
-
-    expect(bars[0]).toHaveAttribute('title', AUDIT_STATUS.done);
-    expect(bars[0]).toHaveTextContent(AUDIT_STATUS.done);
-
-    const detailsLinks = getAllByTestId('details-link');
-
-    expect(detailsLinks[0]).toHaveTextContent('Done');
-    expect(detailsLinks[0]).toHaveAttribute('href', '/auditreport/1234');
-
-    // Report
-    expect(detailsLinks[1]).toHaveTextContent('Wed, Jul 10, 2019 2:51 PM CEST');
-    expect(detailsLinks[1]).toHaveAttribute('href', '/auditreport/1234');
-
-    // Compliance Status
-    expect(bars[1]).toHaveAttribute('title', '50%');
-    expect(bars[1]).toHaveTextContent('50%');
-
-    // Actions
-    const icons = getAllByTestId('svg-icon');
-
-    expect(icons[0]).toHaveAttribute('title', 'Start');
-    expect(icons[1]).toHaveAttribute('title', 'Audit is not stopped');
-    expect(icons[2]).toHaveAttribute('title', 'Move Audit to trashcan');
-    expect(icons[3]).toHaveAttribute('title', 'Edit Audit');
-    expect(icons[4]).toHaveAttribute('title', 'Clone Audit');
-    expect(icons[5]).toHaveAttribute('title', 'Export Audit');
-    expect(icons[6]).toHaveAttribute(
-      'title',
-      'Download Greenbone Compliance Report',
-    );
-  });
-});
\ No newline at end of file
