@@ -4,7 +4,7 @@
  */
 
 import React, {useState, useEffect} from 'react';
-import PropTypes from 'prop-types';
+import {useSearchParams} from 'react-router-dom';
 
 import styled from 'styled-components';
 
@@ -54,6 +54,7 @@ const ToolBarIcons = () => (
 
 const CvssV2Calculator = props => {
   const [, renewSession] = useUserSessionTimeout();
+  const [searchParams] = useSearchParams();
 
   const [state, setState] = useState({
     accessVector: 'Local',
@@ -68,18 +69,15 @@ const CvssV2Calculator = props => {
   });
 
   useEffect(() => {
-    const {location} = props;
+    const cvssVector = searchParams.get('cvssVector');
 
     if (
-      isDefined(location) &&
-      isDefined(location.query) &&
-      isDefined(location.query.cvssVector)
+      cvssVector &&
+      !cvssVector.includes('CVSS:3') &&
+      !cvssVector.includes('CVSS:4')
     ) {
-      const {cvssVector} = location.query;
-      if (!cvssVector.includes('CVSS:3')) {
-        setState(vals => ({...vals, cvssVector, userVector: cvssVector}));
-        handleVectorChange();
-      }
+      setState(vals => ({...vals, cvssVector, userVector: cvssVector}));
+      handleVectorChange();
     }
     // eslint-disable-next-line react-hooks/exhaustive-deps
   }, []);
@@ -211,7 +209,6 @@ const CvssV2Calculator = props => {
           ]}
           name="accessVector"
           value={accessVector}
-          menuPosition="adjust"
           onChange={handleMetricsChange}
         />
       </FormGroup>
@@ -233,7 +230,6 @@ const CvssV2Calculator = props => {
           ]}
           name="accessComplexity"
           value={accessComplexity}
-          menuPosition="adjust"
           onChange={handleMetricsChange}
         />
       </FormGroup>
@@ -255,7 +251,6 @@ const CvssV2Calculator = props => {
           ]}
           name="authentication"
           value={authentication}
-          menuPosition="adjust"
           onChange={handleMetricsChange}
         />
       </FormGroup>
@@ -298,7 +293,6 @@ const CvssV2Calculator = props => {
           ]}
           name="integrityImpact"
           value={integrityImpact}
-          menuPosition="adjust"
           onChange={handleMetricsChange}
         />
       </FormGroup>
@@ -320,7 +314,6 @@ const CvssV2Calculator = props => {
           ]}
           name="availabilityImpact"
           value={availabilityImpact}
-          menuPosition="adjust"
           onChange={handleMetricsChange}
         />
       </FormGroup>
@@ -351,6 +344,7 @@ const CvssV2Calculator = props => {
 
 const CvssV3Calculator = props => {
   const [, renewSession] = useUserSessionTimeout();
+  const [searchParams] = useSearchParams();
 
   const [state, setState] = useState({
     attackVector: 'Network',
@@ -367,18 +361,11 @@ const CvssV3Calculator = props => {
   });
 
   useEffect(() => {
-    const {location} = props;
+    const cvssVector = searchParams.get('cvssVector');
 
-    if (
-      isDefined(location) &&
-      isDefined(location.query) &&
-      isDefined(location.query.cvssVector)
-    ) {
-      const {cvssVector} = location.query;
-      if (cvssVector.includes('CVSS:3')) {
-        setState(vals => ({...vals, cvssVector, userVector: cvssVector}));
-        handleVectorChange();
-      }
+    if (cvssVector?.includes('CVSS:3')) {
+      setState(vals => ({...vals, cvssVector, userVector: cvssVector}));
+      handleVectorChange();
     }
     // eslint-disable-next-line react-hooks/exhaustive-deps
   }, []);
@@ -527,7 +514,6 @@ const CvssV3Calculator = props => {
           ]}
           name="attackVector"
           value={attackVector}
-          menuPosition="adjust"
           onChange={handleMetricsChange}
         />
       </FormGroup>
@@ -545,7 +531,6 @@ const CvssV3Calculator = props => {
           ]}
           name="attackComplexity"
           value={attackComplexity}
-          menuPosition="adjust"
           onChange={handleMetricsChange}
         />
       </FormGroup>
@@ -567,7 +552,6 @@ const CvssV3Calculator = props => {
           ]}
           name="privilegesRequired"
           value={privilegesRequired}
-          menuPosition="adjust"
           onChange={handleMetricsChange}
         />
       </FormGroup>
@@ -585,7 +569,6 @@ const CvssV3Calculator = props => {
           ]}
           name="userInteraction"
           value={userInteraction}
-          menuPosition="adjust"
           onChange={handleMetricsChange}
         />
       </FormGroup>
@@ -603,7 +586,6 @@ const CvssV3Calculator = props => {
           ]}
           name="scope"
           value={scope}
-          menuPosition="adjust"
           onChange={handleMetricsChange}
         />
       </FormGroup>
@@ -646,7 +628,6 @@ const CvssV3Calculator = props => {
           ]}
           name="integrityImpact"
           value={integrityImpact}
-          menuPosition="adjust"
           onChange={handleMetricsChange}
         />
       </FormGroup>
@@ -668,7 +649,6 @@ const CvssV3Calculator = props => {
           ]}
           name="availabilityImpact"
           value={availabilityImpact}
-          menuPosition="adjust"
           onChange={handleMetricsChange}
         />
       </FormGroup>
@@ -701,19 +681,20 @@ const CvssCalculator = props => (
       {/* span prevents Toolbar from growing */}
       <ToolBarIcons />
     </span>
-    <Divider margin="20px" flex="row" align={['center', 'start']} grow>
-      <CvssV2Calculator {...props} />
-      <CvssV3Calculator {...props} />
-    </Divider>
-    <Divider margin="20px" flex="row" align={['center', 'start']} grow>
-      <CvssV4Calculator location={props.location} />
+    <Divider margin="20px" flex="row" align={['flex-start', 'start']} grow wrap>
+      <Layout flex="1" grow>
+        <CvssV2Calculator {...props} />
+      </Layout>
+      <Layout flex="1" grow>
+        <CvssV3Calculator {...props} />
+      </Layout>
+      <Layout flex="1" grow>
+        <CvssV4Calculator />
+      </Layout>
     </Divider>
   </Layout>
 );
 
-CvssCalculator.propTypes = {
-  location: PropTypes.object.isRequired,
-};
 export default CvssCalculator;
 
 // vim: set ts=2 sw=2 tw=80:
