@@ -10,18 +10,28 @@ import styled from 'styled-components';
 import _ from 'gmp/locale';
 
 import Logo from 'web/components/img/greenbone';
-import Divider from 'web/components/layout/divider';
 
 const StyledLogo = styled(Logo)`
   width: 300px;
+  margin-bottom: 20px;
+`;
+
+const CenteredDiv = styled.div`
+  display: flex;
+  flex-direction: column;
+  align-items: center;
+  justify-content: center;
+  text-align: center;
+  height: 80vh;
+  width: 100%;
 `;
 
 const PageNotFound = () => (
-  <Divider flex="column" align={['center', 'center']} grow>
+  <CenteredDiv>
     <h1>{_('Page Not Found.')}</h1>
     <StyledLogo />
     <p>{_('We are sorry. The page you have requested could not be found.')}</p>
-  </Divider>
+  </CenteredDiv>
 );
 
 export default PageNotFound;
