@@ -3,10 +3,10 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
 import React from 'react';
 
 import {connect} from 'react-redux';
+import {withRouter} from 'web/utils/withRouter';
 
 import _ from 'gmp/locale';
 
@@ -15,7 +15,8 @@ import logger from 'gmp/log';
 import Filter, {
   ALL_FILTER,
   RESET_FILTER,
-  RESULTS_FILTER_FILTER} from 'gmp/models/filter';
+  RESULTS_FILTER_FILTER,
+} from 'gmp/models/filter';
 import {isActive} from 'gmp/models/task';
 
 import {first} from 'gmp/utils/array';
@@ -75,7 +76,7 @@ import withGmp from 'web/utils/withGmp';
 import TargetComponent from '../targets/component';
 
 import Page from './deltadetailscontent';
-import FilterDialog from './detailsfilterdialog';
+import ReportDetailsFilterDialog from './detailsfilterdialog';
 
 const log = logger.getLogger('web.pages.report.deltadetailspage');
 
@@ -99,7 +100,6 @@ const getFilter = (entity = {}) => {
 class DeltaReportDetails extends React.Component {
   constructor(...args) {
     super(...args);
-
     this.state = {
       activeTab: 0,
       showFilterDialog: false,
@@ -318,7 +318,7 @@ class DeltaReportDetails extends React.Component {
       includeOverrides,
       reportConfigId,
       reportFormatId,
-      storeAsDefault
+      storeAsDefault,
     } = state;
 
     const newFilter = reportFilter.copy();
@@ -519,7 +519,7 @@ class DeltaReportDetails extends React.Component {
           )}
         </TargetComponent>
         {showFilterDialog && (
-          <FilterDialog
+          <ReportDetailsFilterDialog
             filter={reportFilter}
             delta={true}
             onFilterChanged={this.handleFilterChange}
@@ -564,7 +564,6 @@ DeltaReportDetails.propTypes = {
   loadSettings: PropTypes.func.isRequired,
   loadTarget: PropTypes.func.isRequired,
   location: PropTypes.object.isRequired,
-  match: PropTypes.object.isRequired,
   reload: PropTypes.func.isRequired,
   reportComposerDefaults: PropTypes.object,
   reportExportFileName: PropTypes.string,
@@ -605,8 +604,9 @@ const mapDispatchToProps = (dispatch, {gmp}) => {
   };
 };
 
-const mapStateToProps = (rootState, {match}) => {
-  const {id, deltaid} = match.params;
+const mapStateToProps = (rootState, {params}) => {
+  const {id, deltaid} = params;
+
   const filterSel = filterSelector(rootState);
   const deltaSel = deltaReportSelector(rootState);
   const reportFormatsSel = reportFormatsSelector(rootState);
@@ -708,6 +708,7 @@ export default compose(
   withGmp,
   withDialogNotification,
   withDownload,
+  withRouter,
   connect(mapStateToProps, mapDispatchToProps),
 )(DeltaReportDetailsWrapper);
 
