@@ -241,16 +241,14 @@ describe('Scan Config Detailspage tests', () => {
 
     store.dispatch(entityLoadingActions.success('12345', config));
 
-    const {baseElement, element, getAllByTestId} = render(
-      <Detailspage id="12345" />,
-    );
+    const {baseElement, getAllByTestId} = render(<Detailspage id="12345" />);
 
-    expect(element).toBeVisible();
-    expect(element).toHaveTextContent('Scan Config: foo');
+    expect(baseElement).toBeVisible();
+    expect(baseElement).toHaveTextContent('Scan Config: foo');
 
     const links = baseElement.querySelectorAll('a');
     const icons = getAllByTestId('svg-icon');
-    const detailslinks = getAllByTestId('details-link');
+    const detailsLinks = getAllByTestId('details-link');
 
     expect(icons[0]).toHaveAttribute('title', 'Help: ScanConfigs');
     expect(links[0]).toHaveAttribute(
@@ -261,20 +259,20 @@ describe('Scan Config Detailspage tests', () => {
     expect(links[1]).toHaveAttribute('href', '/scanconfigs');
     expect(icons[1]).toHaveAttribute('title', 'ScanConfig List');
 
-    expect(element).toHaveTextContent('12345');
-    expect(element).toHaveTextContent('Tue, Jul 16, 2019 8:31 AM CEST');
-    expect(element).toHaveTextContent('Tue, Jul 16, 2019 8:44 AM CEST');
-    expect(element).toHaveTextContent('admin');
+    expect(baseElement).toHaveTextContent('12345');
+    expect(baseElement).toHaveTextContent('Tue, Jul 16, 2019 8:31 AM CEST');
+    expect(baseElement).toHaveTextContent('Tue, Jul 16, 2019 8:44 AM CEST');
+    expect(baseElement).toHaveTextContent('admin');
 
-    expect(element).toHaveTextContent('bar');
+    expect(baseElement).toHaveTextContent('bar');
 
-    expect(element).toHaveTextContent('task1');
-    expect(detailslinks[0]).toHaveAttribute('href', '/task/1234');
+    expect(baseElement).toHaveTextContent('task1');
+    expect(detailsLinks[0]).toHaveAttribute('href', '/task/1234');
 
-    expect(element).toHaveTextContent('task2');
-    expect(detailslinks[1]).toHaveAttribute('href', '/task/5678');
+    expect(baseElement).toHaveTextContent('task2');
+    expect(detailsLinks[1]).toHaveAttribute('href', '/task/5678');
 
-    expect(element).not.toHaveTextContent('scanner');
+    expect(baseElement).not.toHaveTextContent('scanner');
   });
 
   test('should render nvt families tab', () => {
@@ -309,19 +307,17 @@ describe('Scan Config Detailspage tests', () => {
 
     store.dispatch(entityLoadingActions.success('12345', config));
 
-    const {baseElement, element, getAllByTestId} = render(
-      <Detailspage id="12345" />,
-    );
+    const {baseElement, getAllByTestId} = render(<Detailspage id="12345" />);
 
     const spans = baseElement.querySelectorAll('span');
     fireEvent.click(spans[12]);
 
-    expect(element).toHaveTextContent('family1');
-    expect(element).toHaveTextContent('1 of 1');
-    expect(element).toHaveTextContent('family2');
-    expect(element).toHaveTextContent('2 of 4');
-    expect(element).toHaveTextContent('family3');
-    expect(element).toHaveTextContent('0 of 2');
+    expect(baseElement).toHaveTextContent('family1');
+    expect(baseElement).toHaveTextContent('1 of 1');
+    expect(baseElement).toHaveTextContent('family2');
+    expect(baseElement).toHaveTextContent('2 of 4');
+    expect(baseElement).toHaveTextContent('family3');
+    expect(baseElement).toHaveTextContent('0 of 2');
 
     const links = baseElement.querySelectorAll('a');
 
@@ -393,9 +389,7 @@ describe('Scan Config Detailspage tests', () => {
 
     store.dispatch(entityLoadingActions.success('12345', config));
 
-    const {baseElement, element, getAllByTestId} = render(
-      <Detailspage id="12345" />,
-    );
+    const {baseElement, getAllByTestId} = render(<Detailspage id="12345" />);
 
     const spans = baseElement.querySelectorAll('span');
     fireEvent.click(spans[14]);
@@ -404,18 +398,18 @@ describe('Scan Config Detailspage tests', () => {
 
     expect(detailsLinks[0]).toHaveAttribute('href', '/nvt/0');
     expect(detailsLinks[0]).toHaveTextContent('nvt0');
-    expect(element).toHaveTextContent('value2');
-    expect(element).toHaveTextContent('value1');
+    expect(baseElement).toHaveTextContent('value2');
+    expect(baseElement).toHaveTextContent('value1');
 
     expect(detailsLinks[1]).toHaveAttribute('href', '/nvt/1');
     expect(detailsLinks[1]).toHaveTextContent('nvt1');
-    expect(element).toHaveTextContent('yes');
-    expect(element).toHaveTextContent('no');
+    expect(baseElement).toHaveTextContent('yes');
+    expect(baseElement).toHaveTextContent('no');
 
     expect(detailsLinks[2]).toHaveAttribute('href', '/nvt/2');
     expect(detailsLinks[2]).toHaveTextContent('nvt2');
-    expect(element).toHaveTextContent('foo');
-    expect(element).toHaveTextContent('bar');
+    expect(baseElement).toHaveTextContent('foo');
+    expect(baseElement).toHaveTextContent('bar');
   });
 
   test('should render user tags tab', () => {
@@ -461,12 +455,12 @@ describe('Scan Config Detailspage tests', () => {
 
     store.dispatch(entityLoadingActions.success('12345', config));
 
-    const {baseElement, element} = render(<Detailspage id="12345" />);
+    const {baseElement} = render(<Detailspage id="12345" />);
 
     const spans = baseElement.querySelectorAll('span');
     fireEvent.click(spans[16]);
 
-    expect(element).toHaveTextContent('No user tags available');
+    expect(baseElement).toHaveTextContent('No user tags available');
   });
 
   test('should render permissions tab', () => {
@@ -501,12 +495,12 @@ describe('Scan Config Detailspage tests', () => {
 
     store.dispatch(entityLoadingActions.success('12345', config));
 
-    const {baseElement, element} = render(<Detailspage id="12345" />);
+    const {baseElement} = render(<Detailspage id="12345" />);
 
     const spans = baseElement.querySelectorAll('span');
     fireEvent.click(spans[18]);
 
-    expect(element).toHaveTextContent('No permissions available');
+    expect(baseElement).toHaveTextContent('No permissions available');
   });
 
   test('should call commands', async () => {
