@@ -13,29 +13,6 @@ import Header from './header';
 import Row from './row';
 import ScanConfigDetails from './details';
 
-export const SORT_FIELDS = [
-  {
-    name: 'name',
-    displayName: _l('Name'),
-  },
-  {
-    name: 'families_total',
-    displayName: _l('Families: Total'),
-  },
-  {
-    name: 'families_trend',
-    displayName: _l('Families: Trend'),
-  },
-  {
-    name: 'nvts_total',
-    displayName: _l('NVTs: Total'),
-  },
-  {
-    name: 'nvts_trend',
-    displayName: _l('NVTs: Trend'),
-  },
-];
-
 const ScanConfigsTable = createEntitiesTable({
   emptyTitle: _l('No Scan Configs available'),
   header: Header,
