@@ -5,8 +5,6 @@
 
 import React from 'react';
 
-import _ from 'gmp/locale';
-
 import SaveDialog from 'web/components/dialog/savedialog';
 
 import FormGroup from 'web/components/form/formgroup';
@@ -14,6 +12,8 @@ import TextField from 'web/components/form/textfield';
 
 import PropTypes from 'web/utils/proptypes';
 
+import useTranslation from 'web/hooks/useTranslation';
+
 import {MAX_TITLE_LENGTH} from './newdashboarddialog';
 
 const EditDashboardDialog = ({
@@ -21,34 +21,32 @@ const EditDashboardDialog = ({
   dashboardTitle,
   onClose,
   onSave,
-}) => (
-  <SaveDialog
-    title={_('Edit Dashboard')}
-    width="550px"
-    minHeight={165}
-    minWidth={340}
-    defaultValues={{
-      dashboardId,
-      dashboardTitle,
-    }}
-    onClose={onClose}
-    onSave={onSave}
-  >
-    {({values, onValueChange}) => (
-      <React.Fragment>
-        <FormGroup title={_('Dashboard Title')} titleSize={4}>
+}) => {
+  const [_] = useTranslation();
+  return (
+    <SaveDialog
+      title={_('Edit Dashboard')}
+      defaultValues={{
+        dashboardId,
+        dashboardTitle,
+      }}
+      onClose={onClose}
+      onSave={onSave}
+    >
+      {({values, onValueChange}) => (
+        <FormGroup title={_('Dashboard Title')}>
           <TextField
-            grow
+            grow="1"
             name="dashboardTitle"
             maxLength={MAX_TITLE_LENGTH}
             value={values.dashboardTitle}
             onChange={onValueChange}
           />
         </FormGroup>
-      </React.Fragment>
-    )}
-  </SaveDialog>
-);
+      )}
+    </SaveDialog>
+  );
+};
 
 EditDashboardDialog.propTypes = {
   dashboardId: PropTypes.id.isRequired,
@@ -58,5 +56,3 @@ EditDashboardDialog.propTypes = {
 };
 
 export default EditDashboardDialog;
-
-// vim: set ts=2 sw=2 tw=80:
