@@ -14,6 +14,16 @@ import Credential, {
 import {rendererWith, fireEvent, screen} from 'web/utils/testing';
 
 import TargetDialog from 'web/pages/targets/dialog';
+import {
+  changeInputValue,
+  getDialogCloseButton,
+  getDialogSaveButton,
+  getFileInputs,
+  getRadioInputs,
+  queryAllSelectElements,
+  getSelectItemElementsForSelect,
+  getTextInputs,
+} from 'web/components/testing';
 
 const cred1 = Credential.fromElement({
   _id: '5678',
@@ -68,118 +78,84 @@ describe('TargetDialog component tests', () => {
       />,
     );
 
-    const inputs = baseElement.querySelectorAll('input');
-    const formgroups = screen.getAllByTestId('formgroup-title');
-    const radioTitles = screen.getAllByTestId('radio-title');
-    const radioInputs = screen.getAllByTestId('radio-input');
+    const inputs = getTextInputs();
+    const fileInputs = getFileInputs();
+    const radioInputs = getRadioInputs();
 
-    expect(radioInputs.length).toEqual(10);
-
-    expect(formgroups[0]).toHaveTextContent('Name');
     expect(inputs[0]).toHaveAttribute('name', 'name');
-    expect(inputs[0]).toHaveAttribute('value', 'Unnamed'); // name field
+    expect(inputs[0]).toHaveValue('Unnamed'); // name field
 
-    expect(formgroups[1]).toHaveTextContent('Comment');
     expect(inputs[1]).toHaveAttribute('name', 'comment');
-    expect(inputs[1]).toHaveAttribute('value', ''); // comment field
+    expect(inputs[1]).toHaveValue(''); // comment field
 
-    expect(formgroups[2]).toHaveTextContent('Hosts');
-    expect(radioTitles[0]).toHaveTextContent('Manual');
     expect(radioInputs[0]).toHaveAttribute('name', 'target_source');
     expect(radioInputs[0]).toHaveAttribute('value', 'manual');
-    expect(radioInputs[0]).toHaveAttribute('checked');
+    expect(radioInputs[0]).toBeChecked();
 
-    expect(inputs[3]).toHaveAttribute('name', 'hosts');
-    expect(inputs[3]).toHaveAttribute('value', '');
+    expect(inputs[2]).toHaveAttribute('name', 'hosts');
+    expect(inputs[2]).toHaveValue('');
 
-    expect(radioTitles[1]).toHaveTextContent('From file');
     expect(radioInputs[1]).toHaveAttribute('name', 'target_source');
     expect(radioInputs[1]).toHaveAttribute('value', 'file');
-    expect(radioInputs[1]).not.toHaveAttribute('checked');
+    expect(radioInputs[1]).not.toBeChecked();
 
-    expect(inputs[5]).toHaveAttribute('name', 'file');
-    expect(inputs[5]).toHaveAttribute('disabled');
+    expect(fileInputs[0]).toBeDisabled();
 
-    expect(formgroups[3]).toHaveTextContent('Exclude Hosts');
-    expect(radioTitles[2]).toHaveTextContent('Manual');
     expect(radioInputs[2]).toHaveAttribute('name', 'target_exclude_source');
     expect(radioInputs[2]).toHaveAttribute('value', 'manual');
-    expect(radioInputs[2]).toHaveAttribute('checked');
+    expect(radioInputs[2]).toBeChecked();
 
-    expect(inputs[7]).toHaveAttribute('name', 'exclude_hosts');
-    expect(inputs[7]).toHaveAttribute('value', '');
+    expect(inputs[3]).toHaveAttribute('name', 'exclude_hosts');
+    expect(inputs[3]).toHaveValue('');
 
-    expect(radioTitles[3]).toHaveTextContent('From file');
     expect(radioInputs[3]).toHaveAttribute('name', 'target_exclude_source');
     expect(radioInputs[3]).toHaveAttribute('value', 'file');
-    expect(radioInputs[3]).not.toHaveAttribute('checked');
+    expect(radioInputs[3]).not.toBeChecked();
 
-    expect(inputs[9]).toHaveAttribute('name', 'exclude_file');
-    expect(inputs[9]).toHaveAttribute('disabled');
+    expect(fileInputs[1]).toBeDisabled();
 
-    expect(formgroups[4]).toHaveTextContent(
-      'Allow simultaneous scanning via multiple IPs',
-    );
-    expect(radioTitles[4]).toHaveTextContent('Yes');
     expect(radioInputs[4]).toHaveAttribute('value', '1');
-    expect(radioInputs[4]).toHaveAttribute('checked');
+    expect(radioInputs[4]).toBeChecked();
 
-    expect(radioTitles[5]).toHaveTextContent('No');
     expect(radioInputs[5]).toHaveAttribute('name', 'allowSimultaneousIPs');
     expect(radioInputs[5]).toHaveAttribute('value', '0');
-    expect(radioInputs[5]).not.toHaveAttribute('checked');
+    expect(radioInputs[5]).not.toBeChecked();
 
-    const selectedValues = screen.getAllByTestId('select-selected-value');
+    const selects = queryAllSelectElements();
 
     expect(baseElement).not.toHaveTextContent('Elevate privileges'); // elevate privileges should not be rendered without valid ssh_credential_id
-    expect(selectedValues.length).toEqual(6); // Should only have 6 selects
 
-    expect(formgroups[5]).toHaveTextContent('Port List');
-    expect(selectedValues[0]).toHaveTextContent('OpenVAS Default');
+    expect(selects[0]).toHaveValue('OpenVAS Default');
     expect(
       screen.getAllByTitle('Create a new port list')[0],
     ).toBeInTheDocument();
 
-    expect(formgroups[6]).toHaveTextContent('Alive Test');
-    expect(selectedValues[1]).toHaveTextContent('Scan Config Default');
+    expect(selects[1]).toHaveValue('Scan Config Default');
 
     const createCredentialIcons = screen.getAllByTitle(
       'Create a new credential',
     );
     expect(createCredentialIcons.length).toEqual(8); // Each icon has both a span and an svg icon. There should be 4 total
 
-    expect(formgroups[7]).toHaveTextContent('SSH');
-    expect(selectedValues[2]).toHaveTextContent('--');
+    expect(selects[2]).toHaveValue('--');
     expect(baseElement).toHaveTextContent('on port');
+    expect(selects[3]).toHaveValue('--');
+    expect(selects[4]).toHaveValue('--');
+    expect(selects[5]).toHaveValue('--');
 
-    expect(formgroups[8]).toHaveTextContent('SMB');
-    expect(selectedValues[3]).toHaveTextContent('--');
-
-    expect(formgroups[9]).toHaveTextContent('ESXi');
-    expect(selectedValues[4]).toHaveTextContent('--');
-
-    expect(formgroups[10]).toHaveTextContent('SNMP');
-    expect(selectedValues[5]).toHaveTextContent('--');
-
-    expect(formgroups[11]).toHaveTextContent('Reverse Lookup Only');
-    expect(radioTitles[6]).toHaveTextContent('Yes');
     expect(radioInputs[6]).toHaveAttribute('value', '1');
-    expect(radioInputs[6]).not.toHaveAttribute('checked');
+    expect(radioInputs[6]).not.toBeChecked();
 
-    expect(radioTitles[7]).toHaveTextContent('No');
     expect(radioInputs[7]).toHaveAttribute('name', 'reverse_lookup_only');
     expect(radioInputs[7]).toHaveAttribute('value', '0');
-    expect(radioInputs[7]).toHaveAttribute('checked');
+    expect(radioInputs[7]).toBeChecked();
 
-    expect(formgroups[12]).toHaveTextContent('Reverse Lookup Unify');
-    expect(radioTitles[8]).toHaveTextContent('Yes');
     expect(radioInputs[8]).toHaveAttribute('value', '1');
-    expect(radioInputs[8]).not.toHaveAttribute('checked');
+    expect(radioInputs[8]).not.toBeChecked();
 
-    expect(radioTitles[9]).toHaveTextContent('No');
     expect(radioInputs[9]).toHaveAttribute('name', 'reverse_lookup_unify');
     expect(radioInputs[9]).toHaveAttribute('value', '0');
-    expect(radioInputs[9]).toHaveAttribute('checked');
+    expect(radioInputs[9]).toBeChecked();
   });
 
   test('should display value from props', () => {
@@ -218,116 +194,82 @@ describe('TargetDialog component tests', () => {
       />,
     );
 
-    const inputs = baseElement.querySelectorAll('input');
-    const formgroups = screen.getAllByTestId('formgroup-title');
-    const radioTitles = screen.getAllByTestId('radio-title');
-    const radioInputs = screen.getAllByTestId('radio-input');
+    const inputs = getTextInputs();
+    const radioInputs = getRadioInputs();
+    const fileInputs = getFileInputs();
+    const selects = queryAllSelectElements();
 
-    expect(radioInputs.length).toEqual(10);
-
-    expect(formgroups[0]).toHaveTextContent('Name');
     expect(inputs[0]).toHaveAttribute('name', 'name');
-    expect(inputs[0]).toHaveAttribute('value', 'target'); // name field
+    expect(inputs[0]).toHaveValue('target'); // name field
 
-    expect(formgroups[1]).toHaveTextContent('Comment');
     expect(inputs[1]).toHaveAttribute('name', 'comment');
-    expect(inputs[1]).toHaveAttribute('value', 'hello world'); // comment field
+    expect(inputs[1]).toHaveValue('hello world'); // comment field
 
-    expect(formgroups[2]).toHaveTextContent('Hosts');
-    expect(radioTitles[0]).toHaveTextContent('Manual');
     expect(radioInputs[0]).toHaveAttribute('name', 'target_source');
     expect(radioInputs[0]).toHaveAttribute('value', 'manual');
-    expect(radioInputs[0]).toHaveAttribute('checked');
+    expect(radioInputs[0]).toBeChecked();
 
-    expect(inputs[3]).toHaveAttribute('name', 'hosts');
-    expect(inputs[3]).toHaveAttribute('value', '123.455.67.434');
+    expect(inputs[2]).toHaveAttribute('name', 'hosts');
+    expect(inputs[2]).toHaveAttribute('value', '123.455.67.434');
 
-    expect(radioTitles[1]).toHaveTextContent('From file');
     expect(radioInputs[1]).toHaveAttribute('name', 'target_source');
     expect(radioInputs[1]).toHaveAttribute('value', 'file');
-    expect(radioInputs[1]).not.toHaveAttribute('checked');
+    expect(radioInputs[1]).not.toBeChecked();
 
-    expect(inputs[5]).toHaveAttribute('name', 'file');
-    expect(inputs[5]).toHaveAttribute('disabled');
+    expect(fileInputs[0]).toHaveAttribute('disabled');
 
-    expect(formgroups[3]).toHaveTextContent('Exclude Hosts');
-    expect(radioTitles[2]).toHaveTextContent('Manual');
     expect(radioInputs[2]).toHaveAttribute('name', 'target_exclude_source');
     expect(radioInputs[2]).toHaveAttribute('value', 'manual');
-    expect(radioInputs[2]).toHaveAttribute('checked');
+    expect(radioInputs[2]).toBeChecked();
 
-    expect(inputs[7]).toHaveAttribute('name', 'exclude_hosts');
-    expect(inputs[7]).toHaveAttribute('value', '');
+    expect(inputs[3]).toHaveAttribute('name', 'exclude_hosts');
+    expect(inputs[3]).toHaveValue('');
 
-    expect(radioTitles[3]).toHaveTextContent('From file');
     expect(radioInputs[3]).toHaveAttribute('name', 'target_exclude_source');
     expect(radioInputs[3]).toHaveAttribute('value', 'file');
-    expect(radioInputs[3]).not.toHaveAttribute('checked');
+    expect(radioInputs[3]).not.toBeChecked();
 
-    expect(inputs[9]).toHaveAttribute('name', 'exclude_file');
-    expect(inputs[9]).toHaveAttribute('disabled');
+    expect(fileInputs[1]).toBeDisabled();
 
-    expect(formgroups[4]).toHaveTextContent(
-      'Allow simultaneous scanning via multiple IPs',
-    );
-    expect(radioTitles[4]).toHaveTextContent('Yes');
     expect(radioInputs[4]).toHaveAttribute('value', '1');
-    expect(radioInputs[4]).not.toHaveAttribute('checked');
+    expect(radioInputs[4]).not.toBeChecked();
 
-    expect(radioTitles[5]).toHaveTextContent('No');
     expect(radioInputs[5]).toHaveAttribute('name', 'allowSimultaneousIPs');
     expect(radioInputs[5]).toHaveAttribute('value', '0');
-    expect(radioInputs[5]).toHaveAttribute('checked');
+    expect(radioInputs[5]).toBeChecked();
 
-    const selectedValues = screen.getAllByTestId('select-selected-value');
-    expect(selectedValues.length).toEqual(6);
-
-    expect(formgroups[5]).toHaveTextContent('Port List');
-    expect(selectedValues[0]).toHaveTextContent('OpenVAS Default');
+    expect(selects[0]).toHaveValue('OpenVAS Default');
     expect(
       screen.getAllByTitle('Create a new port list')[0],
     ).toBeInTheDocument();
 
-    expect(formgroups[6]).toHaveTextContent('Alive Test');
-    expect(selectedValues[1]).toHaveTextContent('Scan Config Default');
+    expect(selects[1]).toHaveValue('Scan Config Default');
 
     const createCredentialIcons = screen.getAllByTitle(
       'Create a new credential',
     );
     expect(createCredentialIcons.length).toEqual(8); // Each icon has both a span and an svg icon. There should be 4 total
 
-    expect(formgroups[7]).toHaveTextContent('SSH');
-    expect(selectedValues[2]).toHaveTextContent('--');
     expect(baseElement).toHaveTextContent('on port');
 
-    expect(formgroups[8]).toHaveTextContent('SMB');
-    expect(selectedValues[3]).toHaveTextContent('username+password');
+    expect(selects[2]).toHaveValue('--');
+    expect(selects[3]).toHaveValue('username+password');
+    expect(selects[4]).toHaveValue('--');
+    expect(selects[5]).toHaveValue('--');
 
-    expect(formgroups[9]).toHaveTextContent('ESXi');
-    expect(selectedValues[4]).toHaveTextContent('--');
-
-    expect(formgroups[10]).toHaveTextContent('SNMP');
-    expect(selectedValues[5]).toHaveTextContent('--');
-
-    expect(formgroups[11]).toHaveTextContent('Reverse Lookup Only');
-    expect(radioTitles[6]).toHaveTextContent('Yes');
     expect(radioInputs[6]).toHaveAttribute('value', '1');
-    expect(radioInputs[6]).not.toHaveAttribute('checked');
+    expect(radioInputs[6]).not.toBeChecked();
 
-    expect(radioTitles[7]).toHaveTextContent('No');
     expect(radioInputs[7]).toHaveAttribute('name', 'reverse_lookup_only');
     expect(radioInputs[7]).toHaveAttribute('value', '0');
-    expect(radioInputs[7]).toHaveAttribute('checked');
+    expect(radioInputs[7]).toBeChecked();
 
-    expect(formgroups[12]).toHaveTextContent('Reverse Lookup Unify');
-    expect(radioTitles[8]).toHaveTextContent('Yes');
     expect(radioInputs[8]).toHaveAttribute('value', '1');
-    expect(radioInputs[8]).not.toHaveAttribute('checked');
+    expect(radioInputs[8]).not.toBeChecked();
 
-    expect(radioTitles[9]).toHaveTextContent('No');
     expect(radioInputs[9]).toHaveAttribute('name', 'reverse_lookup_unify');
     expect(radioInputs[9]).toHaveAttribute('value', '0');
-    expect(radioInputs[9]).toHaveAttribute('checked');
+    expect(radioInputs[9]).toBeChecked();
   });
 
   test('should allow to change values and save the dialog', () => {
@@ -338,7 +280,7 @@ describe('TargetDialog component tests', () => {
 
     const {render} = rendererWith({gmp, capabilities: true});
 
-    const {getByTestId, getByName, getAllByName} = render(
+    const {getByName, getAllByName} = render(
       <TargetDialog
         credentials={credentials}
         id={'foo'}
@@ -368,22 +310,21 @@ describe('TargetDialog component tests', () => {
 
     // text input
     const nameInput = getByName('name');
-    fireEvent.change(nameInput, {target: {value: 'ross'}});
+    changeInputValue(nameInput, 'ross');
 
     // radio input
     const simultaneousIPInput = getAllByName('allowSimultaneousIPs');
     expect(simultaneousIPInput.length).toBe(2);
 
-    expect(simultaneousIPInput[0]).not.toHaveAttribute('checked');
+    expect(simultaneousIPInput[0]).not.toBeChecked();
     expect(simultaneousIPInput[0]).toHaveAttribute('value', '1');
 
-    expect(simultaneousIPInput[1]).toHaveAttribute('checked');
+    expect(simultaneousIPInput[1]).toBeChecked();
     expect(simultaneousIPInput[1]).toHaveAttribute('value', '0');
 
     fireEvent.click(simultaneousIPInput[0]); // radio button check yes
 
-    const saveButton = getByTestId('dialog-save-button');
-
+    const saveButton = getDialogSaveButton();
     fireEvent.click(saveButton);
 
     expect(handleSave).toHaveBeenCalledWith({
@@ -450,8 +391,8 @@ describe('TargetDialog component tests', () => {
 
     expect(baseElement).toHaveTextContent('Elevate privileges');
 
-    const selectedValues = screen.getAllByTestId('select-selected-value');
-    expect(selectedValues.length).toEqual(7); // Should have 7 selects
+    const selects = queryAllSelectElements();
+    expect(selects.length).toEqual(7); // Should have 7 selects
 
     const createCredentialIcons = screen.getAllByTitle(
       'Create a new credential',
@@ -459,7 +400,7 @@ describe('TargetDialog component tests', () => {
     expect(createCredentialIcons.length).toEqual(10); // Each icon has both a span and an svg icon. There should be 5 total, including elevate privileges
   });
 
-  test('ssh elevate credential dropdown should only allow username + password options and remove ssh credential from list', () => {
+  test('ssh elevate credential dropdown should only allow username + password options and remove ssh credential from list', async () => {
     const handleClose = testing.fn();
     const handleChange = testing.fn();
     const handleSave = testing.fn();
@@ -467,7 +408,7 @@ describe('TargetDialog component tests', () => {
 
     const {render} = rendererWith({gmp, capabilities: true});
 
-    const {baseElement, queryAllByTestId} = render(
+    const {baseElement} = render(
       <TargetDialog
         credentials={credentials}
         id={'foo'}
@@ -498,24 +439,17 @@ describe('TargetDialog component tests', () => {
 
     expect(baseElement).toHaveTextContent('Elevate privileges');
 
-    const selectedValues = screen.getAllByTestId('select-selected-value');
-    expect(selectedValues.length).toEqual(7); // Should have 7 selects
+    const selects = queryAllSelectElements();
+    expect(selects.length).toEqual(7); // Should have 7 selects
 
-    const selectOpenButton = screen.getAllByTestId('select-open-button');
-    let selectItems = queryAllByTestId('select-item');
-
-    expect(selectItems.length).toBe(0);
-
-    fireEvent.click(selectOpenButton[3]);
-
-    selectItems = queryAllByTestId('select-item');
+    const selectItems = await getSelectItemElementsForSelect(selects[3]);
     expect(selectItems.length).toBe(2); // "original" ssh option removed
 
     expect(selectItems[0]).toHaveTextContent('--'); // null option
     expect(selectItems[1]).toHaveTextContent('up2');
   });
 
-  test('ssh credential dropdown should remove ssh elevate credential from list', () => {
+  test('ssh credential dropdown should remove ssh elevate credential from list', async () => {
     const handleClose = testing.fn();
     const handleChange = testing.fn();
     const handleSave = testing.fn();
@@ -523,7 +457,7 @@ describe('TargetDialog component tests', () => {
 
     const {render} = rendererWith({gmp, capabilities: true});
 
-    const {baseElement, queryAllByTestId} = render(
+    const {baseElement} = render(
       <TargetDialog
         credentials={credentials}
         id={'foo'}
@@ -554,17 +488,10 @@ describe('TargetDialog component tests', () => {
 
     expect(baseElement).toHaveTextContent('Elevate privileges');
 
-    const selectedValues = screen.getAllByTestId('select-selected-value');
-    expect(selectedValues.length).toEqual(7); // Should have 7 selects
+    const selects = queryAllSelectElements();
+    expect(selects.length).toEqual(7); // Should have 7 selects
 
-    const selectOpenButton = screen.getAllByTestId('select-open-button');
-    let selectItems = queryAllByTestId('select-item');
-
-    expect(selectItems.length).toBe(0);
-
-    fireEvent.click(selectOpenButton[2]);
-
-    selectItems = queryAllByTestId('select-item');
+    const selectItems = await getSelectItemElementsForSelect(selects[2]);
     expect(selectItems.length).toBe(3); // ssh elevate option removed
 
     expect(selectItems[0]).toHaveTextContent('--'); // null option
@@ -614,26 +541,26 @@ describe('TargetDialog component tests', () => {
     const newIcons = queryAllByTitle('Create a new credential');
     expect(newIcons.length).toBe(0); // no new credential can be created
 
-    const selectedValues = screen.getAllByTestId('select-selected-value');
-    expect(selectedValues.length).toEqual(7); // Should have 7 selects
+    const selects = queryAllSelectElements();
+    expect(selects.length).toEqual(7); // Should have 7 selects
 
-    expect(selectedValues[0]).toHaveTextContent('OpenVAS Default');
-    expect(selectedValues[0]).toHaveAttribute('disabled');
+    expect(selects[0]).toHaveValue('OpenVAS Default');
+    expect(selects[0]).toBeDisabled();
 
-    expect(selectedValues[1]).toHaveTextContent('Scan Config Default');
-    expect(selectedValues[2]).toHaveTextContent('username+password');
-    expect(selectedValues[2]).toHaveAttribute('disabled');
+    expect(selects[1]).toHaveValue('Scan Config Default');
+    expect(selects[2]).toHaveValue('username+password');
+    expect(selects[2]).toBeDisabled();
 
-    expect(selectedValues[3]).toHaveTextContent('up2');
-    expect(selectedValues[3]).toHaveAttribute('disabled');
-    expect(selectedValues[4]).toHaveTextContent('--');
-    expect(selectedValues[4]).toHaveAttribute('disabled');
+    expect(selects[3]).toHaveValue('up2');
+    expect(selects[3]).toBeDisabled();
+    expect(selects[4]).toHaveValue('--');
+    expect(selects[4]).toBeDisabled();
 
-    expect(selectedValues[5]).toHaveTextContent('--');
-    expect(selectedValues[5]).toHaveAttribute('disabled');
+    expect(selects[5]).toHaveValue('--');
+    expect(selects[5]).toBeDisabled();
 
-    expect(selectedValues[6]).toHaveTextContent('--');
-    expect(selectedValues[6]).toHaveAttribute('disabled');
+    expect(selects[6]).toHaveValue('--');
+    expect(selects[6]).toBeDisabled();
   });
 
   test('should allow to close the dialog', () => {
@@ -644,7 +571,7 @@ describe('TargetDialog component tests', () => {
 
     const {render} = rendererWith({gmp, capabilities: true});
 
-    const {getByTestId} = render(
+    render(
       <TargetDialog
         credentials={credentials}
         onClose={handleClose}
@@ -660,8 +587,7 @@ describe('TargetDialog component tests', () => {
       />,
     );
 
-    const closeButton = getByTestId('dialog-close-button');
-
+    const closeButton = getDialogCloseButton();
     fireEvent.click(closeButton);
 
     expect(handleClose).toHaveBeenCalled();
