@@ -39,8 +39,8 @@ describe('Task Actions tests', () => {
     const handleTaskStart = testing.fn();
     const handleTaskStop = testing.fn();
 
-    const {render} = rendererWith({capabilities: caps});
-    const {baseElement} = render(
+    const {render} = rendererWith({capabilities: caps, store: true});
+    const {element} = render(
       <Actions
         entity={task}
         links={true}
@@ -55,7 +55,7 @@ describe('Task Actions tests', () => {
       />,
     );
 
-    expect(baseElement).toBeVisible();
+    expect(element).toBeInTheDocument();
   });
 
   test('should call click handlers', () => {
@@ -76,7 +76,7 @@ describe('Task Actions tests', () => {
     const handleTaskStart = testing.fn();
     const handleTaskStop = testing.fn();
 
-    const {render} = rendererWith({capabilities: caps});
+    const {render} = rendererWith({capabilities: caps, store: true});
     const {getAllByTestId} = render(
       <Actions
         entity={task}
@@ -137,7 +137,7 @@ describe('Task Actions tests', () => {
     const handleTaskStart = testing.fn();
     const handleTaskStop = testing.fn();
 
-    const {render} = rendererWith({capabilities: wrongCaps});
+    const {render} = rendererWith({capabilities: wrongCaps, store: true});
     const {getAllByTestId} = render(
       <Actions
         entity={task}
@@ -207,7 +207,7 @@ describe('Task Actions tests', () => {
     const handleTaskStart = testing.fn();
     const handleTaskStop = testing.fn();
 
-    const {render} = rendererWith({capabilities: wrongCaps});
+    const {render} = rendererWith({capabilities: wrongCaps, store: true});
     const {getAllByTestId} = render(
       <Actions
         entity={task}
@@ -280,7 +280,7 @@ describe('Task Actions tests', () => {
     const handleTaskStart = testing.fn();
     const handleTaskStop = testing.fn();
 
-    const {render} = rendererWith({capabilities: wrongCaps});
+    const {render} = rendererWith({capabilities: wrongCaps, store: true});
     const {getAllByTestId} = render(
       <Actions
         entity={task}
@@ -347,7 +347,7 @@ describe('Task Actions tests', () => {
     const handleTaskStart = testing.fn();
     const handleTaskStop = testing.fn();
 
-    const {render} = rendererWith({capabilities: caps});
+    const {render} = rendererWith({capabilities: caps, store: true});
     const {getAllByTestId} = render(
       <Actions
         entity={task}
@@ -408,7 +408,7 @@ describe('Task Actions tests', () => {
     const handleTaskStart = testing.fn();
     const handleTaskStop = testing.fn();
 
-    const {render} = rendererWith({capabilities: caps});
+    const {render} = rendererWith({capabilities: caps, store: true});
     const {getAllByTestId} = render(
       <Actions
         entity={task}
@@ -523,7 +523,7 @@ describe('Task Actions tests', () => {
     const handleTaskStart = testing.fn();
     const handleTaskStop = testing.fn();
 
-    const {render} = rendererWith({capabilities: caps});
+    const {render} = rendererWith({capabilities: caps, store: true});
     const {getAllByTestId} = render(
       <Actions
         entity={task}
