@@ -326,13 +326,11 @@ describe('Task Detailspage tests', () => {
 
     store.dispatch(entityLoadingActions.success('12345', task));
 
-    const {baseElement, element, getAllByTestId} = render(
-      <Detailspage id="12345" />,
-    );
+    const {baseElement, getAllByTestId} = render(<Detailspage id="12345" />);
 
-    expect(element).toBeVisible();
+    expect(baseElement).toBeVisible();
 
-    expect(element).toHaveTextContent('Task: foo');
+    expect(baseElement).toHaveTextContent('Task: foo');
 
     const links = baseElement.querySelectorAll('a');
     const icons = getAllByTestId('svg-icon');
@@ -346,39 +344,41 @@ describe('Task Detailspage tests', () => {
     expect(icons[1]).toHaveAttribute('title', 'Task List');
     expect(links[1]).toHaveAttribute('href', '/tasks');
 
-    expect(element).toHaveTextContent('12345');
-    expect(element).toHaveTextContent('Tue, Jul 16, 2019 8:31 AM CEST');
-    expect(element).toHaveTextContent('Tue, Jul 16, 2019 8:44 AM CEST');
-    expect(element).toHaveTextContent('admin');
+    expect(baseElement).toHaveTextContent('12345');
+    expect(baseElement).toHaveTextContent('Tue, Jul 16, 2019 8:31 AM CEST');
+    expect(baseElement).toHaveTextContent('Tue, Jul 16, 2019 8:44 AM CEST');
+    expect(baseElement).toHaveTextContent('admin');
 
-    expect(element).toHaveTextContent('foo');
-    expect(element).toHaveTextContent('bar');
+    expect(baseElement).toHaveTextContent('foo');
+    expect(baseElement).toHaveTextContent('bar');
 
     const progressBars = getAllByTestId('progressbar-box');
     expect(progressBars[0]).toHaveAttribute('title', 'Done');
     expect(progressBars[0]).toHaveTextContent('Done');
 
-    const headings = element.querySelectorAll('h2');
-    const detailslinks = getAllByTestId('details-link');
+    const headings = baseElement.querySelectorAll('h2');
+    const detailsLinks = getAllByTestId('details-link');
 
     expect(headings[1]).toHaveTextContent('Target');
-    expect(detailslinks[2]).toHaveAttribute('href', '/target/5678');
-    expect(element).toHaveTextContent('target1');
+    expect(detailsLinks[2]).toHaveAttribute('href', '/target/5678');
+    expect(baseElement).toHaveTextContent('target1');
 
     expect(headings[2]).toHaveTextContent('Alerts');
-    expect(detailslinks[3]).toHaveAttribute('href', '/alert/91011');
-    expect(element).toHaveTextContent('alert1');
+    expect(detailsLinks[3]).toHaveAttribute('href', '/alert/91011');
+    expect(baseElement).toHaveTextContent('alert1');
 
     expect(headings[3]).toHaveTextContent('Scanner');
-    expect(detailslinks[4]).toHaveAttribute('href', '/scanner/1516');
-    expect(element).toHaveTextContent('scanner1');
-    expect(element).toHaveTextContent('OpenVAS Scanner');
+    expect(detailsLinks[4]).toHaveAttribute('href', '/scanner/1516');
+    expect(baseElement).toHaveTextContent('scanner1');
+    expect(baseElement).toHaveTextContent('OpenVAS Scanner');
 
     expect(headings[4]).toHaveTextContent('Assets');
 
     expect(headings[5]).toHaveTextContent('Scan');
-    expect(element).toHaveTextContent('2 minutes');
-    expect(element).toHaveTextContent('Do not automatically delete reports');
+    expect(baseElement).toHaveTextContent('2 minutes');
+    expect(baseElement).toHaveTextContent(
+      'Do not automatically delete reports',
+    );
   });
 
   test('should render user tags tab', () => {
@@ -439,11 +439,11 @@ describe('Task Detailspage tests', () => {
 
     store.dispatch(entityLoadingActions.success('12345', task2));
 
-    const {baseElement, element} = render(<Detailspage id="12345" />);
+    const {baseElement} = render(<Detailspage id="12345" />);
     const spans = baseElement.querySelectorAll('span');
     fireEvent.click(spans[22]);
 
-    expect(element).toHaveTextContent('No user tags available');
+    expect(baseElement).toHaveTextContent('No user tags available');
   });
 
   test('should render permissions tab', () => {
@@ -493,11 +493,11 @@ describe('Task Detailspage tests', () => {
 
     store.dispatch(entityLoadingActions.success('12345', task2));
 
-    const {baseElement, element} = render(<Detailspage id="12345" />);
+    const {baseElement} = render(<Detailspage id="12345" />);
     const spans = baseElement.querySelectorAll('span');
     fireEvent.click(spans[24]);
 
-    expect(element).toHaveTextContent('No permissions available');
+    expect(baseElement).toHaveTextContent('No permissions available');
   });
 
   test('should call commands', async () => {
@@ -621,6 +621,7 @@ describe('Task ToolBarIcons tests', () => {
       gmp,
       capabilities: caps,
       router: true,
+      store: true,
     });
 
     const {element, getAllByTestId} = render(
@@ -676,6 +677,7 @@ describe('Task ToolBarIcons tests', () => {
       gmp,
       capabilities: caps,
       router: true,
+      store: true,
     });
 
     const {baseElement, getAllByTestId} = render(
@@ -695,17 +697,18 @@ describe('Task ToolBarIcons tests', () => {
     );
 
     const icons = getAllByTestId('svg-icon');
+
     const badgeIcons = getAllByTestId('badge-icon');
     const links = baseElement.querySelectorAll('a');
     const divs = baseElement.querySelectorAll('div');
 
-    fireEvent.click(divs[9]);
+    fireEvent.click(divs[8]);
     expect(handleTaskCreate).toHaveBeenCalled();
-    expect(divs[9]).toHaveTextContent('New Task');
+    expect(divs[8]).toHaveTextContent('New Task');
 
-    fireEvent.click(divs[10]);
+    fireEvent.click(divs[9]);
     expect(handleContainerTaskCreate).toHaveBeenCalled();
-    expect(divs[10]).toHaveTextContent('New Container Task');
+    expect(divs[9]).toHaveTextContent('New Container Task');
 
     fireEvent.click(icons[3]);
     expect(handleTaskClone).toHaveBeenCalledWith(task3);
@@ -771,6 +774,7 @@ describe('Task ToolBarIcons tests', () => {
       gmp,
       capabilities: caps,
       router: true,
+      store: true,
     });
 
     const {baseElement, getAllByTestId} = render(
@@ -794,13 +798,13 @@ describe('Task ToolBarIcons tests', () => {
     const links = baseElement.querySelectorAll('a');
     const divs = baseElement.querySelectorAll('div');
 
-    fireEvent.click(divs[9]);
+    fireEvent.click(divs[8]);
     expect(handleTaskCreate).toHaveBeenCalled();
-    expect(divs[9]).toHaveTextContent('New Task');
+    expect(divs[8]).toHaveTextContent('New Task');
 
-    fireEvent.click(divs[10]);
+    fireEvent.click(divs[9]);
     expect(handleContainerTaskCreate).toHaveBeenCalled();
-    expect(divs[10]).toHaveTextContent('New Container Task');
+    expect(divs[9]).toHaveTextContent('New Container Task');
 
     fireEvent.click(icons[3]);
     expect(handleTaskClone).toHaveBeenCalledWith(task4);
@@ -873,6 +877,7 @@ describe('Task ToolBarIcons tests', () => {
       gmp,
       capabilities: caps,
       router: true,
+      store: true,
     });
 
     const {baseElement, getAllByTestId} = render(
@@ -896,13 +901,13 @@ describe('Task ToolBarIcons tests', () => {
     const links = baseElement.querySelectorAll('a');
     const divs = baseElement.querySelectorAll('div');
 
-    fireEvent.click(divs[9]);
+    fireEvent.click(divs[8]);
     expect(handleTaskCreate).toHaveBeenCalled();
-    expect(divs[9]).toHaveTextContent('New Task');
+    expect(divs[8]).toHaveTextContent('New Task');
 
-    fireEvent.click(divs[10]);
+    fireEvent.click(divs[9]);
     expect(handleContainerTaskCreate).toHaveBeenCalled();
-    expect(divs[10]).toHaveTextContent('New Container Task');
+    expect(divs[9]).toHaveTextContent('New Container Task');
 
     fireEvent.click(icons[3]);
     expect(handleTaskClone).toHaveBeenCalledWith(task5);
@@ -974,6 +979,7 @@ describe('Task ToolBarIcons tests', () => {
       gmp,
       capabilities: caps,
       router: true,
+      store: true,
     });
 
     const {baseElement, getAllByTestId} = render(
@@ -999,13 +1005,13 @@ describe('Task ToolBarIcons tests', () => {
     const links = baseElement.querySelectorAll('a');
     const divs = baseElement.querySelectorAll('div');
 
-    fireEvent.click(divs[9]);
+    fireEvent.click(divs[8]);
     expect(handleTaskCreate).toHaveBeenCalled();
-    expect(divs[9]).toHaveTextContent('New Task');
+    expect(divs[8]).toHaveTextContent('New Task');
 
-    fireEvent.click(divs[10]);
+    fireEvent.click(divs[9]);
     expect(handleContainerTaskCreate).toHaveBeenCalled();
-    expect(divs[10]).toHaveTextContent('New Container Task');
+    expect(divs[9]).toHaveTextContent('New Container Task');
 
     fireEvent.click(icons[3]);
     expect(handleTaskClone).toHaveBeenCalledWith(task2);
@@ -1077,6 +1083,7 @@ describe('Task ToolBarIcons tests', () => {
       gmp,
       capabilities: caps,
       router: true,
+      store: true,
     });
 
     const {baseElement, getAllByTestId} = render(
@@ -1100,13 +1107,13 @@ describe('Task ToolBarIcons tests', () => {
     const links = baseElement.querySelectorAll('a');
     const divs = baseElement.querySelectorAll('div');
 
-    fireEvent.click(divs[9]);
+    fireEvent.click(divs[8]);
     expect(handleTaskCreate).toHaveBeenCalled();
-    expect(divs[9]).toHaveTextContent('New Task');
+    expect(divs[8]).toHaveTextContent('New Task');
 
-    fireEvent.click(divs[10]);
+    fireEvent.click(divs[9]);
     expect(handleContainerTaskCreate).toHaveBeenCalled();
-    expect(divs[10]).toHaveTextContent('New Container Task');
+    expect(divs[9]).toHaveTextContent('New Container Task');
 
     fireEvent.click(icons[3]);
     expect(handleTaskClone).toHaveBeenCalledWith(task6);
@@ -1241,6 +1248,7 @@ describe('Task ToolBarIcons tests', () => {
       gmp,
       capabilities: caps,
       router: true,
+      store: true,
     });
 
     const {baseElement, getAllByTestId} = render(
@@ -1264,13 +1272,13 @@ describe('Task ToolBarIcons tests', () => {
     const links = baseElement.querySelectorAll('a');
     const divs = baseElement.querySelectorAll('div');
 
-    fireEvent.click(divs[9]);
+    fireEvent.click(divs[8]);
     expect(handleTaskCreate).toHaveBeenCalled();
-    expect(divs[9]).toHaveTextContent('New Task');
+    expect(divs[8]).toHaveTextContent('New Task');
 
-    fireEvent.click(divs[10]);
+    fireEvent.click(divs[9]);
     expect(handleContainerTaskCreate).toHaveBeenCalled();
-    expect(divs[10]).toHaveTextContent('New Container Task');
+    expect(divs[9]).toHaveTextContent('New Container Task');
 
     fireEvent.click(icons[3]);
     expect(handleTaskClone).toHaveBeenCalledWith(task8);
