@@ -5,14 +5,15 @@
 
 import React from 'react';
 
-import _ from 'gmp/locale';
-
 import PropTypes from 'web/utils/proptypes';
 
 import FormGroup from 'web/components/form/formgroup';
 import YesNoRadio from 'web/components/form/yesnoradio';
 
+import useTranslation from 'web/hooks/useTranslation';
+
 export const AddResultsToAssetsGroup = ({inAssets, onChange}) => {
+  const [_] = useTranslation();
   return (
     <FormGroup title={_('Add results to Assets')}>
       <YesNoRadio name="in_assets" value={inAssets} onChange={onChange} />
