@@ -6,7 +6,6 @@
 
 import React from 'react';
 
-import _ from 'gmp/locale';
 import {YES_VALUE, NO_VALUE} from 'gmp/parser';
 
 import Checkbox from 'web/components/form/checkbox';
@@ -15,30 +14,34 @@ import Spinner from 'web/components/form/spinner';
 
 import PropTypes from 'web/utils/proptypes';
 
-const SeverityPart = ({defaultSeverity, dynamicSeverity, onChange}) => (
-  <React.Fragment>
-    <FormGroup title={_('Dynamic Severity')} titleSize="3">
+import useTranslation from 'web/hooks/useTranslation';
+
+const SeverityPart = ({defaultSeverity, dynamicSeverity, onChange}) => {
+  const [_] = useTranslation();
+  return (
+    <React.Fragment>
       <Checkbox
+        title={_('Dynamic Severity')}
         name="dynamicSeverity"
         checked={dynamicSeverity === YES_VALUE}
         checkedValue={YES_VALUE}
         unCheckedValue={NO_VALUE}
         onChange={onChange}
       />
-    </FormGroup>
-    <FormGroup title={_('Default Severity')} titleSize="3">
-      <Spinner
-        name="defaultSeverity"
-        value={defaultSeverity}
-        min="0"
-        max="10"
-        step="0.1"
-        type="float"
-        onChange={onChange}
-      />
-    </FormGroup>
-  </React.Fragment>
-);
+      <FormGroup title={_('Default Severity')}>
+        <Spinner
+          name="defaultSeverity"
+          value={defaultSeverity}
+          min="0"
+          max="10"
+          step="0.1"
+          type="float"
+          onChange={onChange}
+        />
+      </FormGroup>
+    </React.Fragment>
+  );
+};
 
 SeverityPart.propTypes = {
   defaultSeverity: PropTypes.number,
