@@ -3,7 +3,6 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
 import React from 'react';
 import {connect} from 'react-redux';
 
@@ -12,8 +11,9 @@ import _ from 'gmp/locale';
 import {ALL_FILTER} from 'gmp/models/filter';
 import {filterEmptyScanConfig} from 'gmp/models/scanconfig';
 import {openVasScannersFilter} from 'gmp/models/scanner';
+import {SYSTEM_DEFAULT} from 'gmp/locale/date';
 
-import {YES_VALUE, parseYesNo} from 'gmp/parser';
+import {YES_VALUE, NO_VALUE, parseYesNo} from 'gmp/parser';
 
 import {hasValue, isDefined} from 'gmp/utils/identity';
 
@@ -95,6 +95,9 @@ import PropTypes from 'web/utils/proptypes';
 import withCapabilities from 'web/utils/withCapabilities';
 import withGmp from 'web/utils/withGmp';
 
+import useCapabilities from 'web/hooks/useCapabilities';
+import useTranslation from 'web/hooks/useTranslation';
+
 import SettingsDialog from './dialog';
 
 const FIRST_COL_WIDTH = '250px';
@@ -128,7 +131,10 @@ SettingTableRow.propTypes = {
   type: PropTypes.string.isRequired,
 };
 
-const ToolBarIcons = ({capabilities, disableEditIcon, onEditSettingsClick}) => {
+const ToolBarIcons = ({disableEditIcon, onEditSettingsClick}) => {
+  const capabilities = useCapabilities();
+  // eslint-disable-next-line no-shadow
+  const [_] = useTranslation();
   const mayEdit = capabilities.mayEdit('setting');
   const editIconTitle = mayEdit
     ? _('Edit My Settings')
@@ -155,7 +161,6 @@ const ToolBarIcons = ({capabilities, disableEditIcon, onEditSettingsClick}) => {
 };
 
 ToolBarIcons.propTypes = {
-  capabilities: PropTypes.capabilities.isRequired,
   disableEditIcon: PropTypes.bool.isRequired,
   onEditSettingsClick: PropTypes.func.isRequired,
 };
@@ -232,23 +237,35 @@ class UserSettings extends React.Component {
     }
   }
 
-  handleSaveSettings(data) {
-    const {gmp} = this.props;
-    const {userInterfaceLanguage = BROWSER_LANGUAGE, timezone} = data;
+  async handleSaveSettings(data) {
+    try {
+      const {gmp} = this.props;
 
-    this.handleInteraction();
+      const {userInterfaceLanguage = BROWSER_LANGUAGE, timezone} = data;
 
-    return gmp.user.saveSettings(data).then(() => {
-      this.closeDialog();
-      this.props.setLocale(
-        userInterfaceLanguage === BROWSER_LANGUAGE
-          ? undefined
-          : userInterfaceLanguage,
-      );
-      this.props.setTimezone(timezone);
+      await gmp.user.saveSettings(data).then(() => {
+        this.closeDialog();
+        this.props.setLocale(
+          userInterfaceLanguage === BROWSER_LANGUAGE
+            ? undefined
+            : userInterfaceLanguage,
+        );
+        this.props.setTimezone(timezone);
 
-      this.loadSettings();
-    });
+        localStorage.setItem(
+          'userInterfaceTimeFormat',
+          data.userInterfaceTimeFormat,
+        );
+        localStorage.setItem(
+          'userInterfaceDateFormat',
+          data.userInterfaceDateFormat,
+        );
+
+        this.loadSettings();
+      });
+    } catch (error) {
+      console.error(error);
+    }
   }
 
   handleValueChange(value, name) {
@@ -269,6 +286,15 @@ class UserSettings extends React.Component {
       targets,
       isLoading = true,
       timezone,
+      userInterfaceDateFormat = {},
+      userInterfaceTimeFormat = {},
+      isUserInterfaceTimeDateDefault = {
+        value:
+          userInterfaceTimeFormat.value === SYSTEM_DEFAULT &&
+          userInterfaceDateFormat.value === SYSTEM_DEFAULT
+            ? YES_VALUE
+            : NO_VALUE,
+      },
       userInterfaceLanguage = {},
       rowsPerPage = {},
       maxRowsPerPage = {},
@@ -318,7 +344,6 @@ class UserSettings extends React.Component {
       certBundFilter,
       dfnCertFilter,
       autoCacheRebuild = {},
-      deltaReportsVersion,
     } = this.props;
 
     alertsFilter = hasValue(alertsFilter) ? alertsFilter : {};
@@ -359,15 +384,13 @@ class UserSettings extends React.Component {
     nvtFilter = hasValue(nvtFilter) ? nvtFilter : {};
     certBundFilter = hasValue(certBundFilter) ? certBundFilter : {};
     dfnCertFilter = hasValue(dfnCertFilter) ? dfnCertFilter : {};
-
     const openVasScanners = scanners.filter(openVasScannersFilter);
 
     return (
-      <React.Fragment>
+      <>
         <PageTitle title={_('My Settings')} />
         <Layout flex="column">
           <ToolBarIcons
-            capabilities={capabilities}
             disableEditIcon={disableEditIcon}
             onEditSettingsClick={this.openDialog}
           />
@@ -378,7 +401,7 @@ class UserSettings extends React.Component {
           {isLoading ? (
             <Loading />
           ) : (
-            <React.Fragment>
+            <>
               <TabLayout grow="1" align={['start', 'end']}>
                 <TabList
                   active={activeTab}
@@ -404,6 +427,23 @@ class UserSettings extends React.Component {
                           <TableData>{_('Timezone')}</TableData>
                           <TableData>{timezone}</TableData>
                         </TableRow>
+                        <TableRow title={userInterfaceTimeFormat.comment}>
+                          <TableData>{_('Time Format')}</TableData>
+                          <TableData>
+                            {userInterfaceTimeFormat.value === SYSTEM_DEFAULT
+                              ? _('System Default')
+                              : `${Number(userInterfaceTimeFormat.value)}h`}
+                          </TableData>
+                        </TableRow>
+                        <TableRow title={userInterfaceDateFormat.comment}>
+                          <TableData>{_('Date Format')}</TableData>
+                          <TableData>
+                            {userInterfaceDateFormat.value === SYSTEM_DEFAULT
+                              ? _('System Default')
+                              : userInterfaceDateFormat.value}
+                          </TableData>
+                        </TableRow>
+                        <TableRow></TableRow>
                         <TableRow>
                           <TableData>{_('Password')}</TableData>
                           <TableData>********</TableData>
@@ -446,12 +486,6 @@ class UserSettings extends React.Component {
                               : ''}
                           </TableData>
                         </TableRow>
-                        <TableRow>
-                          <TableData>
-                            {_('Delta Reports Version (immutable)')}
-                          </TableData>
-                          <TableData>{deltaReportsVersion}</TableData>
-                        </TableRow>
                       </TableBody>
                     </Table>
                   </TabPanel>
@@ -565,14 +599,11 @@ class UserSettings extends React.Component {
                             title={_('Alerts Filter')}
                             type="filter"
                           />
-                          {capabilities.featureEnabled('COMPLIANCE_REPORTS') && (
-                              <SettingTableRow
-                              setting={auditReportsFilter}
-                              title={_('Audit Reports Filter')}
-                              type="filter"
-                              />
-                            )                         
-                          }
+                          <SettingTableRow
+                            setting={auditReportsFilter}
+                            title={_('Audit Reports Filter')}
+                            type="filter"
+                          />
                           <SettingTableRow
                             setting={configsFilter}
                             title={_('Configs Filter')}
@@ -719,7 +750,7 @@ class UserSettings extends React.Component {
                   )}
                 </TabPanels>
               </Tabs>
-            </React.Fragment>
+            </>
           )}
           {dialogVisible && !isLoading && (
             <SettingsDialog
@@ -732,6 +763,11 @@ class UserSettings extends React.Component {
               schedules={schedules}
               targets={targets}
               timezone={timezone}
+              userInterfaceTimeFormat={userInterfaceTimeFormat.value}
+              userInterfaceDateFormat={userInterfaceDateFormat.value}
+              isUserInterfaceTimeDateDefault={
+                isUserInterfaceTimeDateDefault.value
+              }
               userInterfaceLanguage={userInterfaceLanguage.value}
               rowsPerPage={rowsPerPage.value}
               maxRowsPerPage={maxRowsPerPage.value}
@@ -752,10 +788,7 @@ class UserSettings extends React.Component {
               defaultSchedule={defaultSchedule.id}
               defaultTarget={defaultTarget.id}
               alertsFilter={alertsFilter.id}
-              auditReportsFilter={
-                capabilities.featureEnabled('COMPLIANCE_REPORTS')
-                ? auditReportsFilter.id 
-                : undefined}
+              auditReportsFilter={auditReportsFilter.id}
               configsFilter={configsFilter.id}
               credentialsFilter={credentialsFilter.id}
               filtersFilter={filtersFilter.id}
@@ -790,7 +823,7 @@ class UserSettings extends React.Component {
             />
           )}
         </Layout>
-      </React.Fragment>
+      </>
     );
   }
 }
@@ -807,6 +840,7 @@ UserSettings.propTypes = {
   credentials: PropTypes.array,
   credentialsFilter: PropTypes.object,
   cveFilter: PropTypes.object,
+  userInterfaceDateFormat: PropTypes.oneOf(['wdmy', 'wmdy', SYSTEM_DEFAULT]),
   defaultAlert: PropTypes.object,
   defaultEsxiCredential: PropTypes.object,
   defaultOpenvasScanConfig: PropTypes.object,
@@ -818,12 +852,12 @@ UserSettings.propTypes = {
   defaultSnmpCredential: PropTypes.object,
   defaultSshCredential: PropTypes.object,
   defaultTarget: PropTypes.object,
-  deltaReportsVersion: PropTypes.numberOrNumberString,
   detailsExportFileName: PropTypes.object,
   dfnCertFilter: PropTypes.object,
   dynamicSeverity: PropTypes.object,
   filters: PropTypes.array,
   filtersFilter: PropTypes.object,
+  isUserInterfaceTimeDateDefault: PropTypes.oneOfType([YES_VALUE, NO_VALUE]),
   gmp: PropTypes.gmp.isRequired,
   groupsFilter: PropTypes.object,
   hostsFilter: PropTypes.object,
@@ -866,6 +900,7 @@ UserSettings.propTypes = {
   tasksFilter: PropTypes.object,
   ticketsFilter: PropTypes.object,
   timezone: PropTypes.string,
+  userInterfaceTimeFormat: PropTypes.oneOf([12, 24, SYSTEM_DEFAULT]),
   tlsCertificatesFilter: PropTypes.object,
   userInterfaceLanguage: PropTypes.object,
   usersFilter: PropTypes.object,
@@ -875,11 +910,21 @@ UserSettings.propTypes = {
 
 const mapStateToProps = rootState => {
   const userDefaultsSelector = getUserSettingsDefaults(rootState);
+
   const userDefaultFilterSelector = getUserSettingsDefaultFilter(rootState);
 
   const userInterfaceLanguage = userDefaultsSelector.getByName(
     'userinterfacelanguage',
   );
+
+  const userInterfaceTimeFormat = userDefaultsSelector.getByName(
+    'userinterfacetimeformat',
+  );
+
+  const userInterfaceDateFormat = userDefaultsSelector.getByName(
+    'userinterfacedateformat',
+  );
+
   const rowsPerPage = userDefaultsSelector.getByName('rowsperpage');
   const detailsExportFileName = userDefaultsSelector.getByName(
     'detailsexportfilename',
@@ -983,9 +1028,6 @@ const mapStateToProps = rootState => {
   const certBundFilter = userDefaultFilterSelector.getFilter('certbund');
   const dfnCertFilter = userDefaultFilterSelector.getFilter('dfncert');
   const nvtFilter = userDefaultFilterSelector.getFilter('nvt');
-  const deltaReportsVersion = userDefaultsSelector.getValueByName(
-    'deltareportsversion',
-  );
 
   let scanconfigs = scanConfigsSel.getEntities(ALL_FILTER);
   if (isDefined(scanconfigs)) {
@@ -1002,6 +1044,8 @@ const mapStateToProps = rootState => {
     schedules: schedulesSel.getEntities(ALL_FILTER),
     targets: targetsSel.getEntities(ALL_FILTER),
     timezone: getTimezone(rootState),
+    userInterfaceTimeFormat,
+    userInterfaceDateFormat,
     userInterfaceLanguage,
     rowsPerPage,
     detailsExportFileName,
@@ -1052,7 +1096,6 @@ const mapStateToProps = rootState => {
     dfnCertFilter,
     nvtFilter,
     autoCacheRebuild,
-    deltaReportsVersion,
   };
 };
 
